@@ -19,14 +19,14 @@
   R_X_inv <- backsolve(R_X,diag(ncol(R_X)))
   X_pseudo <- tcrossprod(R_X_inv, qr.Q(QR.temp))
   numenv <- new.env()
-  assign("model", m[[dset]], env = numenv)
-  assign("group", group, env = numenv)
-  assign("rawtheta", rawtheta, env = numenv)
-  assign("multimodel", multimodel, env = numenv)
-  assign("thetalist", thetalist, env = numenv)
-  assign("clpindepX", clpindepX, env = numenv)
-  assign("finished", FALSE, env = numenv)
-  assign("returnX", TRUE, env = numenv)
+  assign("model", m[[dset]], envir = numenv)
+  assign("group", group, envir = numenv)
+  assign("rawtheta", rawtheta, envir = numenv)
+  assign("multimodel", multimodel, envir = numenv)
+  assign("thetalist", thetalist, envir = numenv)
+  assign("clpindepX", clpindepX, envir = numenv)
+  assign("finished", FALSE, envir = numenv)
+  assign("returnX", TRUE, envir = numenv)
   if(m[[ dset ]]@clpdep) 
     s_e <- body(selectMethod("residPart", m[[ dset ]]@mod_type)@.Data)
   else s_e <- body(selectMethod("residPart", m[[ dset ]]@mod_type)@.Data)
