@@ -5,6 +5,10 @@
 	model@timedep <- model@weight || model@lclp0 || model@specdisp
 	model@clpdep <- model@timedep
         model@ncomp <- length(model@specpar)
-        model@ncole <- array(model@ncomp, model@nt)
+	if(length(model@nt)==0) {
+        model@ncole <- array(model@ncomp, 1)
+	} else {
+	model@ncole <- array(model@ncomp, model@nt)
+	}
 	model
    }) 
